@@ -61,12 +61,16 @@ OC.L10N.register(
     "Delete" : "Desaniciar",
     "Copy to clipboard" : "Copiar al cartafueyu",
     "Add" : "Amestar",
+    "Tags" : "Etiquetes",
     "Search" : "Guetar",
+    "Date" : "Date",
     "Disabled" : "Deshabilitáu",
     "Enabled" : "Habilitar",
     "Custom" : "Personalizáu",
     "Tag already exists" : "Yá esiste la etiqueta",
     "Remove" : "Desaniciar",
+    "Client ID" : "ID de veceru",
+    "Client secret" : "Veceru secretu",
     "General" : "Xeneral",
     "User" : "Usuariu",
     "Host" : "Agospiu",
