@@ -72,7 +72,9 @@ OC.L10N.register(
     "No message selected" : "Dim neges wedi'i dewis",
     "Delete" : "Dileu",
     "Add" : "Ychwanegu",
+    "Tags" : "Tagiau",
     "Search" : "Chwilio",
+    "Date" : "Date",
     "Disabled" : "Analluogwyd",
     "Enabled" : "Galluogwyd",
     "Custom" : "Cyfaddas",
