@@ -71,13 +71,18 @@ OC.L10N.register(
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
     "Tags" : "Etiquetas",
+    "Select tags" : "Selecciona las etiquetas",
+    "Clear" : "Limpiar",
     "Search" : "Buscar",
+    "Date" : "Fecha",
     "Disabled" : "Deshabilitado",
     "Enabled" : "Habilitado",
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
     "Remove" : "Eliminar",
     "Reset" : "Reiniciar",
+    "Client ID" : "ID del cliente",
+    "Client secret" : "Secreto del cliente",
     "General" : "General",
     "User" : "Ususario",
     "Host" : "Servidor",
