@@ -109,6 +109,7 @@ OC.L10N.register(
     "Plain text" : "Texto simple",
     "Rich text" : "Texto enriquecido",
     "No messages in this mailbox" : "No hay mensajes en esta bandeja",
+    "No messages" : "No hay mensajes",
     "Draft: " : "Borrador:",
     "Unfavorite" : "Desmarcar como favorito",
     "Favorite" : "Favorito",
@@ -144,13 +145,18 @@ OC.L10N.register(
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
     "Tags" : "Etiquetas",
+    "Select tags" : "Selecciona las etiquetas",
+    "Clear" : "Limpiar",
     "Search" : "Buscar",
+    "Date" : "Fecha",
     "Disabled" : "Deshabilitado",
     "Enabled" : "Habilitado",
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
     "Remove" : "Eliminar",
     "Reset" : "Restablecer",
+    "Client ID" : "ID del cliente",
+    "Client secret" : "Secreto del cliente",
     "General" : "General",
     "User" : "Ususario",
     "Host" : "Servidor",
