@@ -1,6 +1,7 @@
 OC.L10N.register(
     "mail",
     {
+    "Embedded message %s" : "Mensaje incrustado %s",
     "Important" : "Importante",
     "Work" : "Trabajo",
     "Personal" : "Personal",
@@ -71,6 +72,7 @@ OC.L10N.register(
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
     "Tags" : "Etiquetas",
+    "Select tags" : "Selecciona las etiquetas",
     "Search" : "Buscar",
     "Date" : "Fecha",
     "Disabled" : "Deshabilitado",
@@ -79,6 +81,8 @@ OC.L10N.register(
     "Add tag" : "Agregar etiqueta",
     "Remove" : "Eliminar",
     "Reset" : "Restablecer",
+    "Client ID" : "ID del cliente",
+    "Client secret" : "Secreto del cliente",
     "General" : "General",
     "User" : "Ususario",
     "Host" : "Servidor",
