@@ -128,9 +128,9 @@ OC.L10N.register(
     "Unset" : "تنظیم نشده است",
     "Add tag" : "برچسب اضافه کنید",
     "Tag already exists" : "تگ از قبل وجود دارد",
+    "Not found" : "پیدا نشد",
     "Mark as unread" : "علامت به عنوان خوانده‌نشده",
     "Mark as read" : "علامت به عنوان خوانده‌شده",
-    "Not found" : "پیدا نشد",
     "Remove" : "حذف",
     "(organizer)" : "(تنظیم کننده)",
     "Untitled event" : "رویداد بدون عنوان",
@@ -145,6 +145,8 @@ OC.L10N.register(
     "Mail app" : "برنامه پست الکترونیکی",
     "The mail app allows users to read mails on their IMAP accounts." : "برنامه نامه الکترونیکی به کاربران این امکان را می دهد تا نامه ها را در حساب های IMAP خود بخوانند.",
     "Reset" : "بازنشاندن",
+    "Client ID" : "شناسه مشتری",
+    "Client secret" : "رمز مشتری",
     "Email: {email}" : "ایمیل: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} on {host}: {port} (رمزگذاری {ssl))",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} on {host}: {port} (رمزگذاری s ssl))",
