@@ -38,12 +38,13 @@ OC.L10N.register(
     "SMTP User" : "SMTP-käyttäjä",
     "SMTP Password" : "SMTP-salasana",
     "Connecting" : "Yhdistetään",
+    "Sign in with Google" : "Kirjaudu sisään Google-tililläsi",
     "Save" : "Tallenna",
     "Connect" : "Yhdistä",
     "Testing authentication" : "Testataan tunnistautumista",
-    "Account created" : "Tili luotu",
     "Account updated" : "Tili päivitetty",
-    "Changes saved" : "Muutokset tallennettu",
+    "IMAP server is not reachable" : "IMAP-palvelin ei ole tavoitettavissa",
+    "SMTP server is not reachable" : "SMTP-palvelin ei ole tavoitettavissa",
     "IMAP connection failed" : "IMAP-yhteys epäonnistui",
     "SMTP connection failed" : "SMTP-yhteys epäonnistui",
     "There was an error while setting up your account" : "Tiliä määrittäessä ilmeni virhe",
@@ -128,7 +129,7 @@ OC.L10N.register(
     "Plain text" : "Raakateksti",
     "Rich text" : "Rikas teksti",
     "No messages in this mailbox" : "Ei viestejä tässä postilaatikossa",
-    "Messages marked as important will show up here" : "Tärkeiksi merkityt viestit näkyvät täällä",
+    "No messages" : "Ei viestejä",
     "Draft: " : "Luonnos: ",
     "This message is unread" : "Tämä viesti on lukematon",
     "Unfavorite" : "Poista suosikeista",
@@ -165,6 +166,7 @@ OC.L10N.register(
     "Event created" : "Tapahtuma luotu",
     "Could not create event" : "Tapahtumaa ei voitu luoda",
     "You accepted this invitation" : "Hyväksyit tämän kutsun",
+    "You have been invited to an event" : "Sinut on kutsuttu tapahtumaan",
     "This event was cancelled" : "Tämä tapahtuma peruttiin",
     "Comment" : "Kommentti",
     "Accept" : "Hyväksy",
@@ -264,8 +266,11 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopioi leikepöydälle",
     "Contact name …" : "Yhteystiedon nimi…",
     "Add" : "Lisää",
+    "Select sender" : "Valitse lähettäjä",
+    "Select recipient" : "Valitse vastaanottaja",
     "Tags" : "Tunnisteet",
     "Select tags" : "Valitse tunnisteet",
+    "Has attachments" : "On liitteitä",
     "Clear" : "Tyhjennä",
     "Search" : "Etsi",
     "Date" : "Päivä",
@@ -287,13 +292,13 @@ OC.L10N.register(
     "Add tag" : "Lisää tunniste",
     "Saving tag …" : "Tallennetaan tunnistetta…",
     "Tag already exists" : "Tunniste on jo olemassa",
+    "Not found" : "Ei löytynyt",
     "Could not load your message thread" : "Viestiketjua ei voitu ladata",
     "Mark as favorite" : "Merkitse suosikiksi",
     "Mark as unread" : "Merkitse lukemattomaksi",
     "Mark as read" : "Merkitse luetuksi",
     "Archive message" : "Arkistoi viesti",
     "Delete message" : "Poista viesti",
-    "Not found" : "Ei löytynyt",
     "Remove" : "Poista",
     "No senders are trusted at the moment." : "Ei luotettuja lähettäjiä tällä hetkellä.",
     "Could not remove trusted sender {sender}" : "Ei voitu poistaa luotettua lähettäjää {sender}",
@@ -319,6 +324,8 @@ OC.L10N.register(
     "Anti Spam" : "Roskapostin esto",
     "The original message will be attached as a \"message/rfc822\" attachment." : "Alkuperäinen viesti asetetaan \"message/rfc822\"-liitteeksi.",
     "Reset" : "Palauta",
+    "Client ID" : "Asiakas-ID",
+    "Client secret" : "Asiakassalasana",
     "Email: {email}" : "Sähköposti: {email}",
     "General" : "Yleiset",
     "IMAP" : "IMAP",
@@ -331,6 +338,7 @@ OC.L10N.register(
     "Enable LDAP aliases integration" : "Käytä LDAP-aliasten integraatiota",
     "Save Config" : "Tallenna asetus",
     "With the settings above, the app will create account settings in the following way:" : "Sovellus luo tiliasetukset yllä olevin asetuksin seuraavasti:",
+    "Account connected" : "Tili yhdistetty",
     "Keyboard shortcut" : "Näppäimistön pikanäppäin",
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Speed up your Mail experience with these quick shortcuts." : "Nopeuta sähköpostikokemustasi näillä pikanäppäimillä.",
