@@ -45,7 +45,6 @@ OC.L10N.register(
     "Writing mode" : "Način pisanja",
     "Preferred writing mode for new messages and replies." : "Željeni način pisanja za nove poruke i odgovore.",
     "Default folders" : "Zadane mape",
-    "The folders to use for drafts, sent messages and deleted messages." : "Mape koje će se upotrebljavati za skice, poslane poruke i izbrisane poruke.",
     "Sieve filter rules" : "Pravila filtra Sieve",
     "Trusted senders" : "Pouzdani pošiljatelji",
     "Mail server" : "Poslužitelj e-pošte",
@@ -108,6 +107,7 @@ OC.L10N.register(
     "Plain text" : "Običan tekst",
     "Rich text" : "Bogat tekst",
     "No messages in this mailbox" : "Nema poruka u ovom sandučiću",
+    "No messages" : "Nema poruka",
     "Draft: " : "Skica: ",
     "Unfavorite" : "Ukloni iz favorita",
     "Favorite" : "Favorit",
@@ -119,8 +119,8 @@ OC.L10N.register(
     "Edit tags" : "Uredi oznake",
     "Move" : "Premjesti",
     "Move thread" : "Premjesti dretvu",
-    "More actions" : "Dodatne radnje",
     "Delete thread" : "Izbriši dretvu",
+    "More actions" : "Dodatne radnje",
     "Edit as new message" : "Uredi kao novu poruku",
     "Create event" : "Stvori događaj",
     "Blind copy recipients only" : "Samo primatelji skrivenih kopija poruke",
@@ -227,6 +227,11 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopiraj u međuspremnik",
     "Contact name …" : "Naziv kontakta…",
     "Add" : "Dodaj",
+    "Tags" : "Oznake",
+    "Select tags" : "Odaberite oznake",
+    "Clear" : "Izbriši",
+    "Search" : "Traži",
+    "Date" : "Datum",
     "Disabled" : "Onemogućeno",
     "Enabled" : "Omogućeno",
     "Sieve Host" : "Sieve poslužitelj",
@@ -252,11 +257,11 @@ OC.L10N.register(
     "Tag already exists" : "Oznaka već postoji",
     "An error occurred, unable to create the tag." : "Došlo je do pogreške, nije moguće stvoriti oznaku.",
     "An error occurred, unable to rename the tag." : "Došlo je do pogreške, nije moguće promijeniti naziv oznake.",
+    "Not found" : "Nije pronađeno",
     "Could not load your message thread" : "Učitavanje vaše dretve poruka nije uspjelo",
     "Mark as unread" : "Označi kao nepročitano",
     "Mark as read" : "Označi kao pročitano",
     "Delete message" : "Izbriši poruku",
-    "Not found" : "Nije pronađeno",
     "Remove" : "Ukloni",
     "No senders are trusted at the moment." : "Trenutno nema pouzdanih pošiljatelja.",
     "Could not remove trusted sender {sender}" : "Nije moguće ukloniti pouzdanog pošiljatelja {sender}",
@@ -309,6 +314,7 @@ OC.L10N.register(
     "Error saving anti spam email addresses" : "Pogreška pri spremanju adresa e-pošte za sprječavanje neželjene pošte",
     "Successfully deleted anti spam reporting email" : "Uspješno izbrisana adresa e-pošte za prijavu neželjene pošte",
     "Error deleting anti spam reporting email" : "Pogreška pri brisanju adrese e-pošte za prijavu neželjene pošte",
+    "Client secret" : "Tajni ključ klijenta",
     "Domain Match: {provisioningDomain}" : "Podudaranje domene: {provisioningDomain}",
     "Email: {email}" : "E-pošta: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} na {host}:{port} ({ssl} šifriranje)",
@@ -334,6 +340,7 @@ OC.L10N.register(
     "Unprovision & Delete Config" : "Ukini dodjelu i izbriši konfiguraciju",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% i %EMAIL% bit će zamijenjeni korisničkim UID-om i e-poštom",
     "With the settings above, the app will create account settings in the following way:" : "Aplikacija će primijeniti navedene postavke i stvoriti račun na sljedeći način:",
+    "Account connected" : "Račun povezan",
     "Keyboard shortcut" : "Tipkovni prečac",
     "Keyboard shortcuts" : "Tipkovni prečaci",
     "Speed up your Mail experience with these quick shortcuts." : "Ubrzajte korištenje e-pošte s pomoću ovih brzih prečaca.",
@@ -342,7 +349,6 @@ OC.L10N.register(
     "Older message" : "Starija poruka",
     "Toggle star" : "Uključi/isključi zvijezdu",
     "Toggle unread" : "Uključi/isključi nepročitano",
-    "Search" : "Traži",
     "Refresh" : "Osvježi",
     "Connect your mail account" : "Poveži svoj račun e-pošte",
     "Itinerary for {type} is not supported yet" : "Raspored za {type} još uvijek nije podržan",
