@@ -92,6 +92,7 @@ OC.L10N.register(
     "Plain text" : "プレーンテキスト",
     "Rich text" : "リッチテキスト",
     "No messages in this mailbox" : "このメールボックスにメッセージはありません",
+    "No messages" : "メッセージはありません",
     "Draft: " : "下書き",
     "Unfavorite" : "お気に入りから外す",
     "Favorite" : "お気に入り",
@@ -206,11 +207,11 @@ OC.L10N.register(
     "Tag already exists" : "タグはすでに存在します",
     "An error occurred, unable to create the tag." : "エラー:タグを作成できませんでした",
     "An error occurred, unable to rename the tag." : "エラー:タグの名前を変更できませんでした",
+    "Not found" : "見つかりませんでした",
     "Could not load your message thread" : "メッセージを読み込めませんでした",
     "Mark as unread" : "未読にする",
     "Mark as read" : "既読にする",
     "Delete message" : "メッセージを削除",
-    "Not found" : "見つかりませんでした",
     "Remove" : "削除",
     "domain" : "ドメイン",
     "(organizer)" : "（主催者）",
@@ -229,6 +230,8 @@ OC.L10N.register(
     "Anti Spam" : "アンチスパム",
     "The original message will be attached as a \"message/rfc822\" attachment." : "元のメッセージは \"message/rfc822\" の形式で添付されます。",
     "Reset" : "リセット",
+    "Client ID" : "クライアント ID",
+    "Client secret" : "クライアントシークレット",
     "Email: {email}" : "メール: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {host}:{port}の{user} ({ssl} 暗号化)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {host}:{port}の{user} ({ssl} 暗号化)",
@@ -240,6 +243,7 @@ OC.L10N.register(
     "SMTP" : "SMTP",
     "Save Config" : "設定を保存",
     "With the settings above, the app will create account settings in the following way:" : "上記の設定では、アプリは次の方法でアカウント設定を作成します：",
+    "Account connected" : "アカウント接続済",
     "Keyboard shortcut" : "キーボードショートカット",
     "Keyboard shortcuts" : "キーボード ショートカット",
     "Speed up your Mail experience with these quick shortcuts." : "ショートカットであなたのメール操作をスピードアップしてください。",
