@@ -1,8 +1,7 @@
 OC.L10N.register(
     "mail",
     {
-    "Auto detect failed. Please use manual mode." : "자동 감지가 실패했습니다. 수동 모드를 사용하십시오.",
-    "Updating account failed: " : "계정 업데이트 실패:",
+    "Embedded message %s" : "포함된 메시지 %s",
     "Important mail" : "중요 메일",
     "Unread mail" : "읽지 않은 메일",
     "Important" : "중요",
@@ -12,9 +11,13 @@ OC.L10N.register(
     "Mails" : "메일",
     "Mail" : "메일",
     "💌 A mail app for Nextcloud" : "Nextcloud 메일 앱",
+    "Drafts are saved in:" : "초안은 다음 위치에 저장:",
+    "Sent messages are saved in:" : "보낸 메시지는 다음 위치에 저장:",
+    "Deleted messages are moved in:" : "삭제된 메시지는 다음 위치로 이동:",
     "Auto" : "자동",
     "Name" : "이름",
     "Mail address" : "메일 주소",
+    "Please enter an email of the format name@example.com" : "name@example.com 형식의 이메일을 입력하세요.",
     "Password" : "암호",
     "Manual" : "수동",
     "IMAP Settings" : "IMAP 설정",
@@ -35,24 +38,34 @@ OC.L10N.register(
     "Connecting" : "연결 중",
     "Save" : "저장",
     "Connect" : "연결",
+    "Account updated" : "계정 업데이트됨",
+    "There was an error while setting up your account" : "계정을 설정하는 중 오류가 발생했습니다",
     "Account settings" : "계정 설정",
     "Change name" : "이름 변경",
     "Signature" : "서명",
     "A signature is added to the text of new messages and replies." : "서명이 새로운 메시지 및 전달 메시지의 텍스트에 추가됩니다.",
     "Writing mode" : "쓰기 모드",
+    "Preferred writing mode for new messages and replies." : "새 메시지 및 답장을 위한 기본 쓰기 모드입니다.",
     "Default folders" : "기본 폴더",
-    "Mail server" : "메일 서버",
     "Trusted senders" : "신뢰할 수 있는 발신자",
+    "Mail server" : "메일 서버",
     "Email address" : "이메일 주소",
     "Add alias" : "별칭 추가",
     "Cancel" : "취소",
     "Add mail account" : "메일 계정 추가",
     "Use Gravatar and favicon avatars" : "Gravatar 및 파비콘 아바타 사용",
+    "Register as application for mail links" : "메일 링크를 어플리케이션으로 등록",
     "Show keyboard shortcuts" : "키보드 단축키 표시",
+    "Looking for a way to encrypt your emails?" : "이메일을 암호화하는 방법을 찾고 계십니까?",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "앱이 상호 작용에 대한 데이터를 수집하도록 허용합니다. 이 데이터를 기반으로 앱이 사용자의 기본 설정에 맞게 조정됩니다. 데이터는 로컬에만 저장됩니다.",
+    "Put my text to the bottom of a reply instead of on top of it." : "내 텍스트를 답장 위가 아니라 답장 맨 아래에 놓기",
+    "Automatically classify importance of new email" : "새 이메일의 중요도 자동 분류",
+    "Could not update preference" : "환경설정을 업데이트할 수 없습니다.",
     "From" : "보낸사람",
     "Select account" : "계정 선택",
     "To" : "받는사람",
     "Contact or email address …" : "연락처 또는 이메일 주소 ...",
+    "Toggle recipients list mode" : "수신자 목록 모드 전환",
     "Cc" : "참조",
     "Bcc" : "숨은참조",
     "No contacts found." : "연락처를 찾을 수 없음",
@@ -61,21 +74,31 @@ OC.L10N.register(
     "The following recipients do not have a PGP key: {recipients}." : "다음의 수신자는 PGP key가 없습니다:{recipients}.",
     "Write message …" : "메시지 작성중...",
     "Saving draft …" : "초안 저장 중...",
+    "Error saving draft" : "초안을 저장하는 중에 오류가 발생했습니다.",
     "Draft saved" : "초안 저장됨",
+    "Save draft" : "초안 저장",
     "Upload attachment" : "첨부 파일 업로드",
     "Add attachment from Files" : "파일 앱에서 첨부 파일 추가",
+    "Send later" : "나중에 보내기",
+    "Enable formatting" : "서식 활성화",
+    "Request a read receipt" : "수신 확인 요청",
     "Encrypt message with Mailvelope" : "Mailvelope로 메세지 암호화",
+    "Send now" : "지금 보내기",
+    "Tomorrow morning" : "내일 아침",
+    "Tomorrow afternoon" : "내일 오후",
+    "Monday morning" : "월요일 아침",
+    "Custom date and time" : "사용자 지정 날짜 및 시간",
     "Enter a date" : "날짜 입력",
     "Uploading attachments …" : "첨부 파일 업로드...",
     "Sending …" : "보내는 중...",
     "Error sending your message" : "당신의 메시지 보내기 오류",
     "Go back" : "뒤로 가기",
     "Retry" : "다시 시도",
+    "Warning sending your message" : "메시지 전송 경고",
     "Message sent!" : "메시지를 보냈습니다!",
     "Send" : "보내기",
     "Encrypt and send" : "암호화해서 보내기",
     "Send unencrypted" : "비암호화 발송",
-    "Uploading {percent}% …" : "{percent}% 업로드 중...",
     "Choose a file to add as attachment" : "첨부할 파일을 선택하십시오",
     "Choose a file to share as a link" : "공유할 링크 파일을 선택하십시오",
     "Set up an account" : "계정 설정",
@@ -94,17 +117,20 @@ OC.L10N.register(
     "Move" : "이동",
     "More actions" : "더 많은 동작",
     "Create event" : "일정 만들기",
+    "Forward" : "전달",
     "Load more" : "더 불러오기",
     "Report this bug" : "이 오류 보고",
     "All day" : "하루 종일",
     "Create" : "생성",
+    "Comment" : "설명",
+    "Accept" : "수락",
+    "Decline" : "거절",
+    "More options" : "더 많은 옵션",
     "Could not open mailbox" : "메일함을 열 수 없음",
     "Choose" : "선택",
     "Important info" : "중요 정보",
-    "Favorites" : "즐겨찾기",
     "Other" : "기타",
     "Reply" : "답장",
-    "Forward" : "전달",
     "Import into calendar" : "달력으로 가져오기",
     "Download attachment" : "첨부 파일 다운로드",
     "Save to Files" : "파일에 저장",
@@ -112,8 +138,7 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "첨부 항목을 저장할 폴더 선택",
     "Save all to Files" : "모두 저장",
     "The images have been blocked to protect your privacy." : "개인 정보를 보호하기 위해 사진을 차단했습니다.",
-    "New message" : "새로운 메시지",
-    "Settings" : "설정",
+    "Show images" : "사진 보이기",
     "Quota" : "할당량",
     "Saving" : "저장 중",
     "Move up" : "위로 이동",
@@ -127,9 +152,16 @@ OC.L10N.register(
     "Clear cache" : "Clear cache",
     "Subscribed" : "구독함",
     "_{total} message_::_{total} messages_" : ["{total} 개의 메시지"],
+    "New message" : "새로운 메시지",
+    "Message" : "메시지",
     "Delete" : "삭제",
     "Copy to clipboard" : "클립보드로 복사",
     "Add" : "추가",
+    "Tags" : "태그",
+    "Select tags" : "태그 선택",
+    "Clear" : "비우기",
+    "Search" : "검색",
+    "Date" : "날짜",
     "Disabled" : "비활성화됨",
     "Enabled" : "활성화됨",
     "Custom" : "사용자 정의",
@@ -140,17 +172,27 @@ OC.L10N.register(
     "Add tag" : "태그 추가",
     "Tag already exists" : "태그가 이미 존재합니다",
     "Not found" : "찾을 수 없음",
+    "Mark as unread" : "읽지 않은 것으로 표시",
+    "Mark as read" : "읽은 것으로 표시",
     "Remove" : "삭제",
+    "Untitled event" : "제목 없는 일정",
     "Airplane" : "여객기",
     "Reservation {id}" : "예약 {id}",
     "Train" : "열차",
+    "The mail app allows users to read mails on their IMAP accounts." : "Mail 앱은 사용자가 자신의 IMAP 계정에서 이메일을 읽을 수 있도록 합니다.",
+    "Allow additional mail accounts" : "추가 이메일 계정 허용",
+    "Allow additional Mail accounts from User Settings" : "사용자 설정에서 추가 이메일 계정 설정을 허용",
     "Reset" : "초기화",
+    "Client ID" : "클라이언트 ID",
+    "Client secret" : "클라이언트 비밀 값",
     "General" : "일반",
     "IMAP" : "IMAP",
     "User" : "사용자",
     "Host" : "호스트",
     "Port" : "포트",
     "SMTP" : "SMTP",
+    "With the settings above, the app will create account settings in the following way:" : "상단의 설정을 통해, 앱은 다음의 방법으로 계정 설정을 생성합니다: ",
+    "Account connected" : "계정 연결됨",
     "Keyboard shortcut" : "키보드 단축키",
     "Keyboard shortcuts" : "키보드 단축키",
     "Speed up your Mail experience with these quick shortcuts." : "빠른 단축키로 메일 사용을 더 빠르게 할 수 있습니다.",
@@ -159,12 +201,13 @@ OC.L10N.register(
     "Older message" : "오래된 메시지",
     "Toggle star" : "별표 전환",
     "Toggle unread" : "읽음/읽지 않음 전환",
-    "Search" : "검색",
     "Refresh" : "새로 고침",
     "Connect your mail account" : "메일 계정에 연결",
+    "To add a mail account, please contact your administrator." : "이메일 계정 추가는 관리자에게 문의하십시오.",
     "All" : "모두",
     "Archive" : "보관",
     "Drafts" : "임시 보관함",
+    "Favorites" : "즐겨찾기",
     "Priority inbox" : "우선 받은편지함",
     "All inboxes" : "모든 받은 편지함",
     "Inbox" : "받은 편지함",
@@ -186,7 +229,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "자동으로 이동하지 않는 경우 여기를 클릭하십시오.",
     "Redirect" : "넘겨주기",
     "The link leads to %s" : "이 링크가 %s을(를) 향함",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "해당 페이지를 방문하지 않으려면 <a href=\"%s\">메일</a>로 돌아갈 수 있습니다.",
     "Continue to %s" : "%s(으)로 이동"
 },
 "nplurals=1; plural=0;");
