@@ -26,15 +26,18 @@ OC.L10N.register(
     "Saving" : "Lagrar",
     "Delete" : "Ta bort",
     "Add" : "Legg til",
+    "Tags" : "Emneord",
+    "Search" : "Search",
+    "Date" : "Dato",
     "Disabled" : "Deaktivert",
     "Set" : "Sett",
     "Remove" : "Fjern",
+    "Client ID" : "Klient-ID",
     "General" : "Generelt",
     "User" : "Bruker",
     "Host" : "Tenar",
     "Port" : "Port",
     "Keyboard shortcuts" : "Tastatursnarvegar",
-    "Search" : "Search",
     "Refresh" : "Last inn på nytt",
     "All" : "Alle",
     "Favorites" : "Favorit",
