@@ -105,6 +105,7 @@ OC.L10N.register(
     "Plain text" : "Testu simple",
     "Rich text" : "Testu formatadu",
     "No messages in this mailbox" : "Perunu messàgiu in custa casella de posta",
+    "No messages" : "Perunu messàgiu",
     "Draft: " : "Brutacòpia:",
     "Unfavorite" : "Boga dae is preferidos",
     "Favorite" : "Preferidu",
@@ -246,11 +247,11 @@ OC.L10N.register(
     "Add tag" : "Agiunghe eticheta",
     "Saving tag …" : "Sarvende s'eticheta ...",
     "An error occurred, unable to create the tag." : "B'at àpidu un'errore, no faghet a creare s'eticheta.",
+    "Not found" : "No agatadu",
     "Could not load your message thread" : "No at fatu a carrigare su messàgiu tuo in sa dibata",
     "Mark as unread" : "Marca comente non lèghidu",
     "Mark as read" : "Marca comente lèghidu",
     "Delete message" : "Cantzella messàgiu",
-    "Not found" : "No agatadu",
     "Remove" : "Boga",
     "No senders are trusted at the moment." : "No b'at imbiantes afidàbiles in custu momentu.",
     "Could not remove trusted sender {sender}" : "No at fatu a nche bogare s'imbiante afidàbile {sender}",
@@ -287,6 +288,8 @@ OC.L10N.register(
     "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Errore cantzellende e boghende•nde sa frunidura a is contos pro \"{domain}\"",
     "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Frunidura a is {count} contos fata in manera curreta. ","Frunidura a is {count} contos fata in manera curreta. "],
     "Reset" : "Torra a impostare",
+    "Client ID" : "ID cliente",
+    "Client secret" : "Segretu de su cliente",
     "Domain Match: {provisioningDomain}" : "Currispondèntzia de domìniu: {provisioningDomain}",
     "Email: {email}" : "Posta eletrònica: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} in {host}:{port} (tzifradura {ssl})",
@@ -311,6 +314,7 @@ OC.L10N.register(
     "Save Config" : "Sarva cunfiguratzione",
     "Unprovision & Delete Config" : "Boga•nche sa frunidura e Cantzella Cunfiguratzione",
     "With the settings above, the app will create account settings in the following way:" : "Cun is impostatziones de antis, s'aplicatzione at a creare is impostatziones de contu in custa manera:",
+    "Account connected" : "Contu collegadu",
     "Keyboard shortcut" : "Curtziadòrgiu de tecladu",
     "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
     "Speed up your Mail experience with these quick shortcuts." : "Faghe s'esperièntzia de Mail prus lestra cun custos curtziadòrgios.",
