@@ -87,6 +87,7 @@ OC.L10N.register(
     "No message found yet" : "Không có tin nhắn nào được tìm thấy",
     "Set up an account" : "Thiết lập một tài khoản",
     "No messages in this mailbox" : "Không có thư nào trong hộp thư này",
+    "No messages" : "Không có tin nhắn",
     "Draft: " : "Bản nháp: ",
     "Favorite" : "Ưa thích",
     "Read" : "Đọc",
@@ -211,10 +212,10 @@ OC.L10N.register(
     "Unset" : "Bỏ cài đặt",
     "Add tag" : "Thêm nhãn",
     "Tag already exists" : "Thẻ đã tồn tại",
+    "Not found" : "Không tìm thấy",
     "Could not load your message thread" : "Không thể tải chuỗi tin nhắn của bạn",
     "Mark as unread" : "Đánh dấu là chưa đọc",
     "Mark as read" : "Đánh dấu đã đọc",
-    "Not found" : "Không tìm thấy",
     "Remove" : "Xóa",
     "No senders are trusted at the moment." : "Không có người gửi nào được tin cậy vào lúc này.",
     "Could not remove trusted sender {sender}" : "Không thể xóa người gửi đáng tin cậy {sender}",
@@ -234,6 +235,7 @@ OC.L10N.register(
     "The mail app allows users to read mails on their IMAP accounts." : "Ứng dụng thư cho phép người dùng đọc thư trên tài khoản IMAP của họ.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Tại đây bạn có thể tìm thấy các cài đặt cho toàn phiên bản. Cài đặt người dùng cụ thể được tìm thấy trong chính ứng dụng (góc dưới bên trái).",
     "Reset" : "Đặt lại",
+    "Client ID" : "ID khách hàng",
     "Email: {email}" : "Thư điện tử: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} trên {host}: {port} (mã hóa {ssl})",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} trên {host}: {port} (mã hóa {ssl})",
