@@ -13,6 +13,7 @@ OC.L10N.register(
     "Mail" : "郵件",
     "💌 A mail app for Nextcloud" : "Nextcloud 的郵件應用程式",
     "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](https://horde.org) libraries.\n- **📬 Want to host your own mail server?** We do not have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 的郵件應用程式**\n\n- **🚀 與其他 Nextcloud 應用程式整合！** 目前有聯絡人、日曆與檔案 – 還會有更多。\n- **📥 多組郵件賬號！** 私人與公司賬號？沒問題，而且有很好的統一收件匣。可連線到任何 IMAP 賬號。\n- **🔒 傳送與接收加密電子郵件！** 使用超棒的 [Mailvelope]（https://mailvelope.com）瀏覽器擴充套件。\n- **🙈 我們並未重新發明輪子！** 以超棒的 [Horde]（https://horde.org）函式庫為基礎。\n- **📬 想要自架郵件伺服器嗎？** 我們不用重新實作此動作，因為您可以設定 [Mail-in-a-Box]（https://mailinabox.email）！",
+    "Your session has expired. The page will be reloaded." : "您的時段已過期。該頁面將重新加載。",
     "Drafts are saved in:" : "草稿儲存於：",
     "Sent messages are saved in:" : "已傳送的郵件儲存於：",
     "Deleted messages are moved in:" : "已刪除的郵件移動至：",
@@ -39,22 +40,28 @@ OC.L10N.register(
     "SMTP Port" : "SMTP 連接埠",
     "SMTP User" : "SMTP 賬號",
     "SMTP Password" : "SMTP 密碼",
+    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "要使 Google 賬戶與此應用程式配合使用，您需要為 Google 啟用雙重認證並生成應用程式密碼。",
     "Connecting" : "連線中",
+    "Reconnect Google account" : "重新連接 Google 賬戶",
+    "Sign in with Google" : "使用 Google 登入",
     "Save" : "儲存",
     "Connect" : "連線",
     "Looking up configuration" : "查找配置",
     "Checking mail host connectivity" : "檢查郵件主機連接",
     "Configuration discovery failed. Please use the manual settings" : "配置發現失敗。 請使用手動設置",
     "Testing authentication" : "測試認證",
-    "Account created" : "賬戶已創建",
+    "Awaiting user consent" : "等待用戶同意",
+    "Account created. Please follow the popup instructions to link your Google account" : "賬戶已創建。請按照彈出說明連結您的 Google 賬戶",
+    "Loading account" : "加載賬戶",
+    "Account updated. Please follow the popup instructions to reconnect your Google account" : "賬戶已更新。請按照彈出說明重新連結您的 Google 賬戶",
     "Account updated" : "賬戶已更新",
-    "Changes saved" : "變更已保存",
     "IMAP server is not reachable" : "IMAP 伺服器無法連線",
     "SMTP server is not reachable" : "SMTP 伺服器無法連線",
     "IMAP username or password is wrong" : "IMAP 用戶名或密碼錯誤",
     "SMTP username or password is wrong" : "SMTP 用戶名或密碼錯誤",
     "IMAP connection failed" : "IMAP 連線失敗",
     "SMTP connection failed" : "SMTP 連線失敗",
+    "Google authorization popup closed" : "Google 授權彈窗關閉",
     "There was an error while setting up your account" : "設置您的帳戶時出錯。 ",
     "Account settings" : "賬號設定",
     "Change name" : "更改名稱",
@@ -148,8 +155,9 @@ OC.L10N.register(
     "Plain text" : "純文字",
     "Rich text" : "RTF",
     "No messages in this mailbox" : "此信箱中沒有郵件",
-    "Messages marked as important will show up here" : "標記為重要的訊息將在此處顯示",
+    "No messages" : "沒有訊息",
     "Draft: " : "草稿：",
+    "Encrypted message" : "加密訊息",
     "This message is unread" : "此訊息未讀",
     "Unfavorite" : "取消我的最愛",
     "Favorite" : "我的最愛",
@@ -209,6 +217,7 @@ OC.L10N.register(
     "{attendeeName} tentatively accepted your invitation" : "{attendeeName} 暫時接受了您的邀請",
     "{attendeeName} declined your invitation" : "{attendeeName} 已婉拒您的邀請",
     "{attendeeName} reacted to your invitation" : "{attendeeName} 已對您的邀請作出反應",
+    "Failed to save your participation status" : "無法保存您的參與狀態",
     "Could not open mailbox" : "無法開啟信箱",
     "Loading messages …" : "正在載入訊息 ...",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "正在索引您的郵件。對於較大的信箱來說，這可能需要較長的時間。",
@@ -254,6 +263,8 @@ OC.L10N.register(
     "Moving thread" : "移動主題",
     "Moving message" : "移動訊息",
     "Mail settings" : "電郵設定",
+    "Provisioned account is disabled" : "預配賬戶已禁用",
+    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "請使用密碼登錄以啟用此賬戶。當前會話正在使用無密碼身份驗證，例如 SSO 或 WebAuthn。",
     "Quota" : "用量",
     "Show only subscribed mailboxes" : "僅顯示已訂閱的信箱",
     "Add mailbox" : "新增信箱",
@@ -312,8 +323,19 @@ OC.L10N.register(
     "Copy to clipboard" : "複製到剪貼板",
     "Contact name …" : "聯絡人名稱 ...",
     "Add" : "新增",
+    "Search in mailbox" : "在郵箱中搜尋",
+    "Search parameters" : "在參數中搜尋",
+    "Search term" : "搜尋字詞",
+    "Pick a start date" : "挑選開始日期",
+    "Pick an end date" : "挑選結束日期",
+    "Select sender" : "選取寄件人",
+    "Select recipient" : "選擇收件人",
+    "Select cc recipient" : "選擇 cc 收件人",
+    "Select bcc recipient" : "選擇 bcc 收件人",
     "Tags" : "標籤",
     "Select tags" : "選擇標籤",
+    "Marked as" : "已標記為",
+    "Has attachments" : "有附件",
     "Clear" : "清除",
     "Search" : "搜尋",
     "Date" : "日期",
@@ -344,14 +366,16 @@ OC.L10N.register(
     "Tag already exists" : "標籤已經存在",
     "An error occurred, unable to create the tag." : "發生錯誤，無法建立標籤。",
     "An error occurred, unable to rename the tag." : "發生錯誤，無法重新命名標籤。",
+    "Loading thread" : "主題加載中",
+    "Not found" : "找不到",
     "Could not load your message thread" : "無法載入您的郵件串",
+    "The thread doesn't exist or has been deleted" : "話題不存在或已被刪除",
     "Mark as unfavorite" : "取消標記我的最愛",
     "Mark as favorite" : "標記為我的最愛",
     "Mark as unread" : "標為未讀",
     "Mark as read" : "標為已讀",
     "Archive message" : "封存郵件",
     "Delete message" : "刪除訊息",
-    "Not found" : "找不到",
     "Remove" : "移除",
     "No senders are trusted at the moment." : "當前沒有發件人是受信任的",
     "Could not remove trusted sender {sender}" : "無法刪除受信任的發件人 {sender}",
@@ -387,6 +411,9 @@ OC.L10N.register(
     "Anti Spam Service" : "反垃圾郵件服務",
     "You can set up an anti spam service email address here." : "您可以在此設定反垃圾郵件服務的電郵地址。",
     "Any email that is marked as spam will be sent to the anti spam service." : "任何被標記為垃圾郵件的電郵會被傳送到反垃圾郵件服務。",
+    "Gmail integration" : "Gmail 整合",
+    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail 允許用戶透過 IMAP 存取他們的電子郵件。出於安全原因，只有使用 OAuth 2.0 連接或使用雙重認證和應用程式密碼的 Google 帳戶才能進行此存取。",
+    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "您必須在 Google Cloud 控制台中為「Web 應用程式」註冊一個新的客戶端 ID。添加 URL {url} 作為授權重定向 URI。",
     "Successfully updated config for \"{domain}\"" : "已成功更新 “{domain}” 的配置",
     "Error saving config" : "存儲配置時發生錯誤",
     "Saved config for \"{domain}\"" : "已成功保存 “{domain}” 的配置",
@@ -406,6 +433,13 @@ OC.L10N.register(
     "Error saving anti spam email addresses" : "儲存反垃圾郵件電郵地址時發生錯誤",
     "Successfully deleted anti spam reporting email" : "成功刪除了反垃圾電郵回報電郵地址",
     "Error deleting anti spam reporting email" : "刪除反垃圾郵件回報電郵時發生錯誤",
+    "Client ID" : "客戶端 ID",
+    "Client secret" : "客戶端密碼",
+    "Unlink" : "取消連結",
+    "Google integration configured" : "已配置 Google 整合",
+    "Could not configure Google integration" : "無法配置 Google 整合",
+    "Google integration unlinked" : "取消 Google 整合鏈接",
+    "Could not unlink Google integration" : "無法取消 Google 整合連結",
     "Domain Match: {provisioningDomain}" : "網域匹配：{provisioningDomain}",
     "Email: {email}" : "電子郵件：{email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP：{user} 在 {host}：{port}（{ssl} 加密）",
@@ -431,6 +465,8 @@ OC.L10N.register(
     "Unprovision & Delete Config" : "取消配置和刪除配置",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% 與 %EMAIL% 將以用戶的 UID 與電郵地址取代",
     "With the settings above, the app will create account settings in the following way:" : "使用上述設定，應用程式將會以下列方式建立賬號：",
+    "Account connected" : "賬戶已連結",
+    "You can close this window" : "可以關閉此視窗",
     "Keyboard shortcut" : "鍵盤快捷鍵",
     "Keyboard shortcuts" : "鍵盤快捷鍵",
     "Speed up your Mail experience with these quick shortcuts." : "這些鍵盤快捷鍵可加快您的郵件使用體驗。",
