@@ -36,6 +36,7 @@ class CreateAccount extends Command {
 	public const ARGUMENT_USER_ID = 'user-id';
 	public const ARGUMENT_NAME = 'name';
 	public const ARGUMENT_EMAIL = 'email';
+	public const ARGUMENT_AUTH_METHOD = 'auth-method';
 	public const ARGUMENT_IMAP_HOST = 'imap-host';
 	public const ARGUMENT_IMAP_PORT = 'imap-port';
 	public const ARGUMENT_IMAP_SSL_MODE = 'imap-ssl-mode';
@@ -47,14 +48,9 @@ class CreateAccount extends Command {
 	public const ARGUMENT_SMTP_USER = 'smtp-user';
 	public const ARGUMENT_SMTP_PASSWORD = 'smtp-password';
 
-	/** @var AccountService */
-	private $accountService;
-
-	/** @var \OCP\Security\ICrypto */
-	private $crypto;
-
-	/** @var IUserManager */
-	private $userManager;
+	private AccountService $accountService;
+	private ICrypto $crypto;
+	private IUserManager $userManager;
 
 	public function __construct(AccountService $service,
 								ICrypto $crypto,
@@ -87,12 +83,15 @@ class CreateAccount extends Command {
 		$this->addArgument(self::ARGUMENT_SMTP_SSL_MODE, InputArgument::REQUIRED);
 		$this->addArgument(self::ARGUMENT_SMTP_USER, InputArgument::REQUIRED);
 		$this->addArgument(self::ARGUMENT_SMTP_PASSWORD, InputArgument::REQUIRED);
+
+		$this->addArgument(self::ARGUMENT_AUTH_METHOD, InputArgument::OPTIONAL, 'password or xoauth2', 'password');
 	}
 
 	protected function execute(InputInterface $input, OutputInterface $output): int {
 		$userId = $input->getArgument(self::ARGUMENT_USER_ID);
 		$name = $input->getArgument(self::ARGUMENT_NAME);
 		$email = $input->getArgument(self::ARGUMENT_EMAIL);
+		$authMethod = $input->getArgument(self::ARGUMENT_AUTH_METHOD);
 
 		$imapHost = $input->getArgument(self::ARGUMENT_IMAP_HOST);
 		$imapPort = $input->getArgument(self::ARGUMENT_IMAP_PORT);
@@ -115,6 +114,7 @@ class CreateAccount extends Command {
 		$account->setUserId($userId);
 		$account->setName($name);
 		$account->setEmail($email);
+		$account->setAuthMethod($authMethod);
 
 		$account->setInboundHost($imapHost);
 		$account->setInboundPort((int) $imapPort);
@@ -128,9 +128,9 @@ class CreateAccount extends Command {
 		$account->setOutboundUser($smtpUser);
 		$account->setOutboundPassword($this->crypto->encrypt($smtpPassword));
 
-		$this->accountService->save($account);
+		$account = $this->accountService->save($account);
 
-		$output->writeln("<info>Account $email created</info>");
+		$output->writeln("<info>Account " . $account->getId() . " for $email created</info>");
 
 		return 0;
 	}
