@@ -40,11 +40,8 @@ use function memory_get_peak_usage;
 class Thread extends Command {
 	public const ARGUMENT_INPUT_FILE = 'thread-file';
 
-	/** @var ThreadBuilder */
-	private $builder;
-
-	/** @var LoggerInterface */
-	private $logger;
+	private ThreadBuilder $builder;
+	private LoggerInterface $logger;
 
 	public function __construct(ThreadBuilder $builder,
 								LoggerInterface $logger) {
