@@ -29,8 +29,8 @@ declare(strict_types=1);
 
 namespace OCA\Mail\Controller;
 
-use Exception;
 use Horde_Imap_Client;
+use OCA\Mail\AppInfo\Application;
 use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Contracts\IMailTransmission;
 use OCA\Mail\Db\Mailbox;
@@ -46,38 +46,22 @@ use OCA\Mail\Service\Sync\SyncService;
 use OCP\AppFramework\Controller;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\JSONResponse;
+use OCP\IConfig;
 use OCP\IL10N;
 use OCP\IRequest;
 use Psr\Log\LoggerInterface;
 
 class AccountsController extends Controller {
-
-	/** @var AccountService */
-	private $accountService;
-
-	/** @var string */
-	private $currentUserId;
-
-	/** @var LoggerInterface */
-	private $logger;
-
-	/** @var IL10N */
-	private $l10n;
-
-	/** @var AliasesService */
-	private $aliasesService;
-
-	/** @var IMailTransmission */
-	private $mailTransmission;
-
-	/** @var SetupService */
-	private $setup;
-
-	/** @var IMailManager */
-	private $mailManager;
-
-	/** @var SyncService */
-	private $syncService;
+	private AccountService $accountService;
+	private string $currentUserId;
+	private LoggerInterface $logger;
+	private IL10N $l10n;
+	private AliasesService $aliasesService;
+	private IMailTransmission $mailTransmission;
+	private SetupService $setup;
+	private IMailManager $mailManager;
+	private SyncService $syncService;
+	private IConfig $config;
 
 	public function __construct(string $appName,
 								   IRequest $request,
@@ -89,7 +73,8 @@ class AccountsController extends Controller {
 								   IMailTransmission $mailTransmission,
 								   SetupService $setup,
 								   IMailManager $mailManager,
-								   SyncService $syncService
+								   SyncService $syncService,
+									IConfig $config
 	) {
 		parent::__construct($appName, $request);
 		$this->accountService = $accountService;
@@ -101,6 +86,7 @@ class AccountsController extends Controller {
 		$this->setup = $setup;
 		$this->mailManager = $mailManager;
 		$this->syncService = $syncService;
+		$this->config = $config;
 	}
 
 	/**
@@ -141,7 +127,6 @@ class AccountsController extends Controller {
 	 * @param int $id
 	 * @param string $accountName
 	 * @param string $emailAddress
-	 * @param string $password
 	 * @param string $imapHost
 	 * @param int $imapPort
 	 * @param string $imapSslMode
@@ -152,16 +137,14 @@ class AccountsController extends Controller {
 	 * @param string $smtpSslMode
 	 * @param string $smtpUser
 	 * @param string $smtpPassword
-	 * @param bool $autoDetect
+	 * @param string $authMethod
 	 *
 	 * @return JSONResponse
 	 * @throws ClientException
 	 */
 	public function update(int $id,
-						   bool $autoDetect,
 						   string $accountName,
 						   string $emailAddress,
-						   string $password = null,
 						   string $imapHost = null,
 						   int $imapPort = null,
 						   string $imapSslMode = null,
@@ -171,7 +154,8 @@ class AccountsController extends Controller {
 						   int $smtpPort = null,
 						   string $smtpSslMode = null,
 						   string $smtpUser = null,
-						   string $smtpPassword = null): JSONResponse {
+						   string $smtpPassword = null,
+						   string $authMethod = 'password'): JSONResponse {
 		try {
 			// Make sure the account actually exists
 			$this->accountService->find($this->currentUserId, $id);
@@ -179,28 +163,26 @@ class AccountsController extends Controller {
 			return new JSONResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
-		$account = null;
-		$errorMessage = null;
 		try {
-			if ($autoDetect) {
-				$account = $this->setup->createNewAutoConfiguredAccount($accountName, $emailAddress, $password);
-			} else {
-				$account = $this->setup->createNewAccount($accountName, $emailAddress, $imapHost, $imapPort, $imapSslMode, $imapUser, $imapPassword, $smtpHost, $smtpPort, $smtpSslMode, $smtpUser, $smtpPassword, $this->currentUserId, $id);
-			}
-		} catch (Exception $ex) {
-			$errorMessage = $ex->getMessage();
-		}
+			return MailJsonResponse::success(
+				$this->setup->createNewAccount($accountName, $emailAddress, $imapHost, $imapPort, $imapSslMode, $imapUser, $imapPassword, $smtpHost, $smtpPort, $smtpSslMode, $smtpUser, $smtpPassword, $this->currentUserId, $authMethod, $id)
+			);
+		} catch (CouldNotConnectException $e) {
+			$data = [
+				'error' => $e->getReason(),
+				'service' => $e->getService(),
+				'host' => $e->getHost(),
+				'port' => $e->getPort(),
+			];
 
-		if (is_null($account)) {
-			if ($autoDetect) {
-				throw new ClientException($this->l10n->t('Auto detect failed. Please use manual mode.'));
-			} else {
-				$this->logger->error('Updating account failed: ' . $errorMessage);
-				throw new ClientException($this->l10n->t('Updating account failed: ') . $errorMessage);
-			}
+			$this->logger->info('Creating account failed: ' . $e->getMessage(), $data);
+			return MailJsonResponse::fail($data);
+		} catch (ServiceException $e) {
+			$this->logger->error('Creating account failed: ' . $e->getMessage(), [
+				'exception' => $e,
+			]);
+			return MailJsonResponse::error('Could not create account');
 		}
-
-		return new JSONResponse($account);
 	}
 
 	/**
@@ -214,6 +196,7 @@ class AccountsController extends Controller {
 	 * @param int|null $draftsMailboxId
 	 * @param int|null $sentMailboxId
 	 * @param int|null $trashMailboxId
+	 * @param int|null $archiveMailboxId
 	 * @param bool|null $signatureAboveQuote
 	 *
 	 * @return JSONResponse
@@ -227,6 +210,7 @@ class AccountsController extends Controller {
 								 int $draftsMailboxId = null,
 								 int $sentMailboxId = null,
 								 int $trashMailboxId = null,
+								 int $archiveMailboxId = null,
 								 bool $signatureAboveQuote = null): JSONResponse {
 		$account = $this->accountService->find($this->currentUserId, $id);
 
@@ -244,6 +228,10 @@ class AccountsController extends Controller {
 			$this->mailManager->getMailbox($this->currentUserId, $trashMailboxId);
 			$dbAccount->setTrashMailboxId($trashMailboxId);
 		}
+		if ($archiveMailboxId !== null) {
+			$this->mailManager->getMailbox($this->currentUserId, $archiveMailboxId);
+			$dbAccount->setarchiveMailboxId($archiveMailboxId);
+		}
 		if ($editorMode !== null) {
 			$dbAccount->setEditorMode($editorMode);
 		}
@@ -257,7 +245,7 @@ class AccountsController extends Controller {
 			$dbAccount->setSignatureAboveQuote($signatureAboveQuote);
 		}
 		return new JSONResponse(
-			$this->accountService->save($dbAccount)->toJson()
+			$this->accountService->save($dbAccount)
 		);
 	}
 
@@ -299,28 +287,41 @@ class AccountsController extends Controller {
 	 *
 	 * @param string $accountName
 	 * @param string $emailAddress
-	 * @param string $password
-	 * @param string $imapHost
-	 * @param int $imapPort
-	 * @param string $imapSslMode
-	 * @param string $imapUser
-	 * @param string $imapPassword
-	 * @param string $smtpHost
-	 * @param int $smtpPort
-	 * @param string $smtpSslMode
-	 * @param string $smtpUser
-	 * @param string $smtpPassword
-	 * @param bool $autoDetect
+	 * @param string|null $imapHost
+	 * @param int|null $imapPort
+	 * @param string|null $imapSslMode
+	 * @param string|null $imapUser
+	 * @param string|null $imapPassword
+	 * @param string|null $smtpHost
+	 * @param int|null $smtpPort
+	 * @param string|null $smtpSslMode
+	 * @param string|null $smtpUser
+	 * @param string|null $smtpPassword
+	 * @param string $authMethod
 	 *
 	 * @return JSONResponse
 	 */
-	public function create(string $accountName, string $emailAddress, string $password = null, string $imapHost = null, int $imapPort = null, string $imapSslMode = null, string $imapUser = null, string $imapPassword = null, string $smtpHost = null, int $smtpPort = null, string $smtpSslMode = null, string $smtpUser = null, string $smtpPassword = null, bool $autoDetect = true): JSONResponse {
+	public function create(string $accountName,
+		string $emailAddress,
+		string $imapHost = null,
+		int $imapPort = null,
+		string $imapSslMode = null,
+		string $imapUser = null,
+		?string $imapPassword = null,
+		string $smtpHost = null,
+		int $smtpPort = null,
+		string $smtpSslMode = null,
+		string $smtpUser = null,
+		?string $smtpPassword = null,
+		string $authMethod = 'password'): JSONResponse {
+		if ($this->config->getAppValue(Application::APP_ID, 'allow_new_mail_accounts', 'yes') === 'no') {
+			$this->logger->info('Creating account disabled by admin.');
+			return MailJsonResponse::error('Could not create account');
+		}
 		try {
-			if ($autoDetect) {
-				$account = $this->setup->createNewAutoConfiguredAccount($accountName, $emailAddress, $password);
-			} else {
-				$account = $this->setup->createNewAccount($accountName, $emailAddress, $imapHost, $imapPort, $imapSslMode, $imapUser, $imapPassword, $smtpHost, $smtpPort, $smtpSslMode, $smtpUser, $smtpPassword, $this->currentUserId);
-			}
+			return MailJsonResponse::success(
+				$this->setup->createNewAccount($accountName, $emailAddress, $imapHost, $imapPort, $imapSslMode, $imapUser, $imapPassword, $smtpHost, $smtpPort, $smtpSslMode, $smtpUser, $smtpPassword, $this->currentUserId, $authMethod), Http::STATUS_CREATED
+			);
 		} catch (CouldNotConnectException $e) {
 			$data = [
 				'error' => $e->getReason(),
@@ -330,22 +331,13 @@ class AccountsController extends Controller {
 			];
 
 			$this->logger->info('Creating account failed: ' . $e->getMessage(), $data);
-			return \OCA\Mail\Http\JsonResponse::fail($data);
+			return MailJsonResponse::fail($data);
 		} catch (ServiceException $e) {
 			$this->logger->error('Creating account failed: ' . $e->getMessage(), [
 				'exception' => $e,
 			]);
-			return \OCA\Mail\Http\JsonResponse::error('Could not create account');
+			return MailJsonResponse::error('Could not create account');
 		}
-
-		if (is_null($account)) {
-			return \OCA\Mail\Http\JsonResponse::fail([
-				'error' => 'AUTOCONFIG_FAILED',
-				'message' => $this->l10n->t('Auto detect failed. Please use manual mode.'),
-			]);
-		}
-
-		return \OCA\Mail\Http\JsonResponse::success($account, Http::STATUS_CREATED);
 	}
 
 	/**
@@ -423,6 +415,6 @@ class AccountsController extends Controller {
 		if ($quota === null) {
 			return MailJsonResponse::fail([], Http::STATUS_NOT_IMPLEMENTED);
 		}
-		return MailJsonResponse::success($quota);
+		return MailJsonResponse::success($quota)->cacheFor(5 * 60, false, true);
 	}
 }
