@@ -46,7 +46,7 @@ use OCP\AppFramework\Db\Entity;
  * @method string getInboundUser()
  * @method void setInboundUser(string $inboundUser)
  * @method string|null getInboundPassword()
- * @method void setInboundPassword(string $inboundPassword)
+ * @method void setInboundPassword(?string $inboundPassword)
  * @method string getOutboundHost()
  * @method void setOutboundHost(string $outboundHost)
  * @method integer getOutboundPort()
@@ -56,7 +56,7 @@ use OCP\AppFramework\Db\Entity;
  * @method string getOutboundUser()
  * @method void setOutboundUser(string $outboundUser)
  * @method string|null getOutboundPassword()
- * @method void setOutboundPassword(string $outboundPassword)
+ * @method void setOutboundPassword(?string $outboundPassword)
  * @method string|null getSignature()
  * @method void setSignature(string|null $signature)
  * @method int getLastMailboxSync()
@@ -77,6 +77,8 @@ use OCP\AppFramework\Db\Entity;
  * @method int|null getSentMailboxId()
  * @method void setTrashMailboxId(?int $id)
  * @method int|null getTrashMailboxId()
+ * @method void setArchiveMailboxId(?int $id)
+ * @method int|null getArchiveMailboxId()
  * @method bool|null isSieveEnabled()
  * @method void setSieveEnabled(bool $sieveEnabled)
  * @method string|null getSieveHost()
@@ -91,8 +93,19 @@ use OCP\AppFramework\Db\Entity;
  * @method void setSievePassword(?string $sievePassword)
  * @method bool|null isSignatureAboveQuote()
  * @method void setSignatureAboveQuote(bool $signatureAboveQuote)
+ * @method string getAuthMethod()
+ * @method void setAuthMethod(string $method)
+ * @method int getSignatureMode()
+ * @method void setSignatureMode(int $signatureMode)
+ * @method string getOauthRefreshToken()
+ * @method void setOauthRefreshToken(string $token)
+ * @method int|null getOauthTokenTtl()
+ * @method void setOauthTokenTtl(int $ttl)
  */
 class MailAccount extends Entity {
+	public const SIGNATURE_MODE_PLAIN = 0;
+	public const SIGNATURE_MODE_HTML = 1;
+
 	protected $userId;
 	protected $name;
 	protected $email;
@@ -112,6 +125,9 @@ class MailAccount extends Entity {
 	protected $order;
 	protected $showSubscribedOnly;
 	protected $personalNamespace;
+	protected $authMethod;
+	protected $oauthRefreshToken;
+	protected $oauthTokenTtl;
 
 	/** @var int|null */
 	protected $draftsMailboxId;
@@ -122,6 +138,9 @@ class MailAccount extends Entity {
 	/** @var int|null */
 	protected $trashMailboxId;
 
+	/** @var int|null */
+	protected $archiveMailboxId;
+
 	/** @var bool */
 	protected $sieveEnabled = false;
 	/** @var string|null */
@@ -140,6 +159,8 @@ class MailAccount extends Entity {
 	/** @var int|null */
 	protected $provisioningId;
 
+	/** @var int */
+	protected $signatureMode;
 
 	/**
 	 * @param array $params
@@ -203,9 +224,11 @@ class MailAccount extends Entity {
 		$this->addType('draftsMailboxId', 'integer');
 		$this->addType('sentMailboxId', 'integer');
 		$this->addType('trashMailboxId', 'integer');
+		$this->addType('archiveMailboxId', 'integer');
 		$this->addType('sieveEnabled', 'boolean');
 		$this->addType('sievePort', 'integer');
 		$this->addType('signatureAboveQuote', 'boolean');
+		$this->addType('signatureMode', 'int');
 	}
 
 	/**
@@ -230,8 +253,10 @@ class MailAccount extends Entity {
 			'draftsMailboxId' => $this->getDraftsMailboxId(),
 			'sentMailboxId' => $this->getSentMailboxId(),
 			'trashMailboxId' => $this->getTrashMailboxId(),
+			'archiveMailboxId' => $this->getArchiveMailboxId(),
 			'sieveEnabled' => ($this->isSieveEnabled() === true),
 			'signatureAboveQuote' => ($this->isSignatureAboveQuote() === true),
+			'signatureMode' => $this->getSignatureMode(),
 		];
 
 		if (!is_null($this->getOutboundHost())) {
