@@ -33,6 +33,7 @@ use Horde_Imap_Client_Ids;
 use Horde_Imap_Client_Socket;
 use Horde_Mime_Mail;
 use Horde_Mime_Part;
+use Html2Text\Html2Text;
 use OCA\Mail\Db\Mailbox;
 use OCA\Mail\Exception\ServiceException;
 use OCA\Mail\Model\IMAPMessage;
@@ -51,7 +52,6 @@ use function reset;
 use function sprintf;
 
 class MessageMapper {
-
 	/** @var LoggerInterface */
 	private $logger;
 
@@ -613,7 +613,7 @@ class MessageMapper {
 			$attachments[] = [
 				'content' => $part->getContents(),
 				'name' => $part->getName(),
-				'size' => $part->getSize()
+				'size' => $part->getBytes()
 			];
 			fclose($stream);
 		}
@@ -665,6 +665,10 @@ class MessageMapper {
 										 array $uids): array {
 		$structureQuery = new Horde_Imap_Client_Fetch_Query();
 		$structureQuery->structure();
+		$structureQuery->headerText([
+			'cache' => true,
+			'peek' => true,
+		]);
 
 		$structures = $client->fetch($mailbox, $structureQuery, [
 			'ids' => new Horde_Imap_Client_Ids($uids),
@@ -673,48 +677,64 @@ class MessageMapper {
 		return array_map(function (Horde_Imap_Client_Data_Fetch $fetchData) use ($mailbox, $client) {
 			$hasAttachments = false;
 			$text = '';
+			$isImipMessage = false;
 
 			$structure = $fetchData->getStructure();
-			foreach ($structure as $part) {
-				if ($part instanceof Horde_Mime_Part && $part->isAttachment()) {
+			/** @var Horde_Mime_Part $part */
+			foreach ($structure->getParts() as $part) {
+				if ($part->isAttachment()) {
 					$hasAttachments = true;
-					break;
+				}
+				$bodyParts = $part->getParts();
+				/** @var Horde_Mime_Part $bodyPart */
+				foreach ($bodyParts as $bodyPart) {
+					$contentParameters = $bodyPart->getAllContentTypeParameters();
+					if ($bodyPart->getType() === 'text/calendar' && isset($contentParameters['method'])) {
+						$isImipMessage = true;
+					}
 				}
 			}
 
-			$textBodyId = $structure->findBody('text');
-			// $htmlBodyId = $structure->findBody('html');
-			// $htmlBody = $data->getBodyPart($htmlBodyId);
-
+			$textBodyId = $structure->findBody() ?? $structure->findBody('text');
+			$htmlBodyId = $structure->findBody('html');
+			if ($textBodyId === null && $htmlBodyId === null) {
+				return new MessageStructureData($hasAttachments, $text, $isImipMessage);
+			}
 			$partsQuery = new Horde_Imap_Client_Fetch_Query();
-			if ($textBodyId === null) {
-				return new MessageStructureData($hasAttachments, $text);
+			if ($htmlBodyId !== null) {
+				$partsQuery->bodyPart($htmlBodyId, [
+					'decode' => true,
+					'peek' => true,
+				]);
+				$partsQuery->mimeHeader($htmlBodyId, [
+					'peek' => true
+				]);
+			}
+			if ($textBodyId !== null) {
+				$partsQuery->bodyPart($textBodyId, [
+					'decode' => true,
+					'peek' => true,
+				]);
+				$partsQuery->mimeHeader($textBodyId, [
+					'peek' => true
+				]);
 			}
-			$partsQuery->bodyPart($textBodyId, [
-				'decode' => true,
-				'peek' => true,
-			]);
-			$partsQuery->mimeHeader($textBodyId, [
-				'peek' => true
-			]);
 			$parts = $client->fetch($mailbox, $partsQuery, [
 				'ids' => new Horde_Imap_Client_Ids([$fetchData->getUid()]),
 			]);
 			/** @var Horde_Imap_Client_Data_Fetch $part */
 			$part = $parts[$fetchData->getUid()];
-			$body = $part->getBodyPart($textBodyId);
-
-			if (!empty($body)) {
-				$mimeHeaders = $fetchData->getMimeHeader($textBodyId, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
-				if ($enc = $mimeHeaders->getValue('content-transfer-encoding')) {
-					$structure->setTransferEncoding($enc);
-				}
-				$structure->setContents($body);
-				/** @var string $text */
-				$text = $structure->getContents();
+			$htmlBody = $part->getBodyPart($htmlBodyId);
+			if (!empty($htmlBody)) {
+				$html = new Html2Text($htmlBody);
+				return new MessageStructureData($hasAttachments, trim($html->getText()), $isImipMessage);
+			}
+			$textBody = $part->getBodyPart($textBodyId);
+			if (!empty($textBody)) {
+				return new MessageStructureData($hasAttachments, $textBody, $isImipMessage);
 			}
 
-			return new MessageStructureData($hasAttachments, $text);
+			return new MessageStructureData($hasAttachments, $text, $isImipMessage);
 		}, iterator_to_array($structures->getIterator()));
 	}
 }
